@@ -9,7 +9,7 @@ use Mojo::SMTP::Client::Exception;
 use Carp;
 use Scalar::Util 'weaken';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 use constant {
 	CMD_OK       => 2,
@@ -48,14 +48,6 @@ has inactivity_timeout => sub { $ENV{MOJO_INACTIVITY_TIMEOUT} // 20 };
 has ioloop             => sub { Mojo::IOLoop->new };
 has autodie            => 0;
 
-my %cmd = (
-	from  => 1,
-	to    => 1,
-	data  => 1,
-	reset => 1,
-	quit  => 1,
-);
-
 sub send {
 	my $self = shift;
 	my $cb = @_ % 2 == 0 ? undef : pop;
